From efe8e2311ee2fed881f95cc1e72825906d21c7c1 Mon Sep 17 00:00:00 2001
From: David Robillard <d@drobilla.net>
Date: Sun, 12 Aug 2012 23:42:17 +0000
Subject: Use ingen:root as the path for the root patch, opening up path space
 for engine/driver/etc. Strict conversion between Path and URI (Path no longer
 is-a URI).

git-svn-id: http://svn.drobilla.net/lad/trunk/ingen@4672 a436a847-0d15-0410-975c-d299462d15a1
---
 src/socket/SocketReader.cpp | 4 ++--
 src/socket/SocketWriter.cpp | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

(limited to 'src/socket')

diff --git a/src/socket/SocketReader.cpp b/src/socket/SocketReader.cpp
index 7599038e..b73b9eb0 100644
--- a/src/socket/SocketReader.cpp
+++ b/src/socket/SocketReader.cpp
@@ -92,9 +92,9 @@ SocketReader::_run()
 	Sord::World*  world = _world.rdf_world();
 	LV2_URID_Map* map   = &_world.uri_map().urid_map_feature()->urid_map;
 
 	// Use <path:> as base URI so e.g. </foo/bar> will be a path
 	SordNode* base_uri = sord_new_uri(
-		world->c_obj(), (const uint8_t*)"path:");
+		world->c_obj(), (const uint8_t*)"ingen:root/");
 
 	// Set up sratom and a forge to build LV2 atoms from model
 	Sratom*        sratom = sratom_new(map);
@@ -92,9 +92,9 @@ SocketReader::_run()
 	LV2_URID_Map* map   = &_world.uri_map().urid_map_feature()->urid_map;
 
-	// Use <path:> as base URI so e.g. </foo/bar> will be a path
+	// Use <ingen:root/> as base URI so e.g. </foo/bar> will be a path
 	SordNode* base_uri = sord_new_uri(
diff --git a/src/socket/SocketWriter.cpp b/src/socket/SocketWriter.cpp
index 8fa5ee05..f66606be 100644
--- a/src/socket/SocketWriter.cpp
+++ b/src/socket/SocketWriter.cpp
@@ -50,8 +50,8 @@ SocketWriter::SocketWriter(URIMap&           map,
 	, _uri(uri)
 	, _socket(sock)
 {
-	// Use <path:> as base URI so e.g. </foo/bar> will be a path
-	_base = serd_node_from_string(SERD_URI, (const uint8_t*)"path:");
+	// Use <ingen:root/> as base URI so e.g. </foo/bar> will be a path
+	_base = serd_node_from_string(SERD_URI, (const uint8_t*)"ingen:root/");
 
 	serd_uri_parse(_base.buf, &_base_uri);
 
-- 
cgit v1.2.1